#
# spec file for package gnome-shell-extensions
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(Meta\\)
Name:           gnome-shell-extensions
Version:        3.26.2
Release:        lp151.8.3.1
Summary:        A collection of extensions for GNOME Shell
License:        GPL-2.0+
Group:          System/GUI/GNOME
Url:            https://wiki.gnome.org/Projects/GnomeShell/Extensions
Source:         https://download.gnome.org/sources/gnome-shell-extensions/3.26/%{name}-%{version}.tar.xz
Source1:        README.SUSE
Source2:        sle-classic.desktop
Source3:        SLE-theme.tar.gz
Source4:        sle-classic-xorg.desktop
Source5:        sle-classic.json
Source6:        sle-classic@suse.com.tar.gz
# PATCH-FEATURE-OPENSUSE gnome-shell-add-app-to-desktop.patch bnc#870580 dliang@suse.com --  allow adding app shortcut to desktop easily.
Patch1:         gnome-shell-add-app-to-desktop.patch
# PATCH-FEATURE-OPENSUSE sle-classic-favorites-menu-at-end.patch bnc#890989 cxiong@suse.com -- put the favorites at the end of the app catogories for accessibility reason -- cxiong@suse.com bnc#890989
Patch2:         gnome-shell-favorites-menu-at-end.patch
# PATCH-FEATURE-SLE sle-classic-lock-screen-background.patch bsc#1007468 xwang@suse.com -- add SUSE logo on lock screen when auth is requested
Patch3:         sle-classic-lock-screen-background.patch
# PATCH-FIX-UPSTREAM gnome-shell-extensions-window-list-app-icon-not-shown.patch bgo#745064 xwang@suse.com -- window-list application icon don't show on taskbar
Patch4:         gnome-shell-extensions-window-list-app-icon-not-shown.patch
# PATCH-FIX-OPENSUSE gnome-classic-s390-not-require-g-s-d_wacom.patch bsc#1129412 yfjiang@suse.com -- Remove the runtime requirement of g-s-d Wacom plugin
Patch5:         gnome-classic-s390-not-require-g-s-d_wacom.patch
## NOTE keep SLE Classic patch at the bottom
# PATCH-FIX-SLE gse-sle-classic-ext.patch Fate#318572 cxiong@suse.com -- add sle classic support
Patch1000:      gse-sle-classic-ext.patch
# Needed because we build a tarball generated with "git archive"
BuildRequires:  gnome-common
# gobject-introspection is needed for the typelib() rpm magic.
BuildRequires:  gnome-patch-translation
# Needed for directory ownership
BuildRequires:  gnome-shell
BuildRequires:  gobject-introspection
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(gio-2.0)

%description
GNOME Shell Extensions is a collection of extensions providing
additional and optional functionality to GNOME Shell.

%package common
Summary:        Common files for GNOME Shell extensions
Group:          System/GUI/GNOME
Requires:       gnome-shell
Recommends:     %{name}-common-lang
# Obsoletes for metapackage and extensions from gnome-shell-extensions that we used to package
Obsoletes:      gnome-shell-extension-alternate-tab < %{version}
Obsoletes:      gnome-shell-extension-apps-menu < %{version}
Obsoletes:      gnome-shell-extension-auto-move-windows < %{version}
Obsoletes:      gnome-shell-extension-dock
Obsoletes:      gnome-shell-extension-drive-menu < %{version}
Obsoletes:      gnome-shell-extension-gajim < %{version}
Obsoletes:      gnome-shell-extension-native-window-placement < %{version}
Obsoletes:      gnome-shell-extension-places-menu < %{version}
Obsoletes:      gnome-shell-extension-systemMonitor < %{version}
Obsoletes:      gnome-shell-extension-user-theme < %{version}
Obsoletes:      gnome-shell-extension-windows-navigator < %{version}
Obsoletes:      gnome-shell-extension-workspace-indicator < %{version}
Obsoletes:      gnome-shell-extension-xrandr-indicator < %{version}
Obsoletes:      gnome-shell-extensions < %{version}
BuildArch:      noarch

%description common
This package provides files common to several GNOME Shell Extensions

%package -n gnome-shell-classic
Summary:        A collection of extensions for Gnome-shell classic
Group:          System/GUI/GNOME
Requires:       gnome-shell-classic-session
Recommends:     %{name}-common-lang
BuildArch:      noarch

%description -n gnome-shell-classic
This GNOME Shell extension adds a power off item in the status
menu, and provides the ability to hibernate.

This package provides the extensions required to switch to gnome-shell classic.

%package -n gnome-shell-classic-session
Summary:        A collection of extensions for Gnome-shell classic
Group:          System/GUI/GNOME

%description -n gnome-shell-classic-session
This packages provides architecture dependent session files to gnome-shell classic.

%lang_package -n %{name}-common

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%if !0%{?is_opensuse}
translation-update-upstream
gnome-patch-translation-prepare
%patch3 -p1
%endif
%patch4 -p1
%ifarch s390 s390x
%patch5 -p1
%endif
%patch1000 -p1
##gnome-patch-translation-update
# In openSUSE GNOME, we don't launch gnome-session directly, but wrap this through a shell script, /usr/bin/gnome
sed -i "s:Exec=gnome-session:Exec=gnome:g" data/gnome-classic.desktop.in
cp %{SOURCE1} .
%if !0%{?is_opensuse}
sed -i -e 's/openSUSE/SUSE Linux Enterprise/g' README.SUSE
%endif

%build
CLASSIC_EXTENSIONS=$(awk -F\" '/^CLASSIC_EXTENSIONS=/{ print $2 }' configure.ac)
CLASSIC_EXTENSIONS="${CLASSIC_EXTENSIONS} workspace-indicator"
%configure \
   --enable-classic-mode \
   --enable-extensions="$CLASSIC_EXTENSIONS"
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} %{?no_lang_C}
install -m0644 %{SOURCE2} %{buildroot}/%{_datadir}/xsessions/sle-classic.desktop
cp %{buildroot}/%{_datadir}/gnome-shell/extensions/window-list@gnome-shell-extensions.gcampax.github.com/classic.css \
%{buildroot}/%{_datadir}/gnome-shell/extensions/window-list@gnome-shell-extensions.gcampax.github.com/sle-classic.css
install -m0644 %{SOURCE5} %{buildroot}/%{_datadir}/gnome-shell/modes/sle-classic.json
install -d -m755 %{buildroot}%{_datadir}/wayland-sessions
install -m0644 %{SOURCE2} %{buildroot}/%{_datadir}/wayland-sessions/sle-classic.desktop
# Install SLE theme
#Install sle-classic@suse.com extension
tar -xzvf %{SOURCE6}
install -d %{buildroot}%{_datadir}/gnome-shell/extensions/sle-classic@suse.com
cp sle-classic@suse.com/*  %{buildroot}%{_datadir}/gnome-shell/extensions/sle-classic@suse.com
%if !0%{?is_opensuse}
install -m0644 %{SOURCE4} %{buildroot}/%{_datadir}/xsessions/sle-classic-xorg.desktop
tar -xzvf %{SOURCE3}
install -d %{buildroot}%{_datadir}/gnome-shell/theme
cp SLE-theme/theme/*  %{buildroot}%{_datadir}/gnome-shell/theme
%endif

%if !0%{?is_opensuse}
# Prepare for 'default.desktop' being update-alternative handled, boo#1039756
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop
touch %{buildroot}%{_sysconfdir}/alternatives/default-waylandsession.desktop
ln -s %{_sysconfdir}/alternatives/default-waylandsession.desktop %{buildroot}%{_datadir}/wayland-sessions/default.desktop
%endif

%if !0%{?is_opensuse}
%post -n gnome-shell-classic
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/sle-classic.desktop 20
%{_sbindir}/update-alternatives --install %{_datadir}/wayland-sessions/default.desktop \
  default-waylandsession.desktop %{_datadir}/wayland-sessions/sle-classic.desktop 20

%postun -n gnome-shell-classic
[ -f %{_datadir}/xsessions/sle-classic.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/sle-classic.desktop
[ -f %{_datadir}/wayland-sessions/sle-classic.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-waylandsession.desktop %{_datadir}/wayland-sessions/sle-classic.desktop
%endif

%files common
%defattr(-,root,root)
%doc COPYING README.SUSE

%files -n gnome-shell-classic
%defattr(-,root,root)
%doc COPYING
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.classic-overrides.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.window-list.gschema.xml
%dir %{_datadir}/gnome-shell/extensions
%{_datadir}/gnome-shell/extensions/alternate-tab@gnome-shell-extensions.gcampax.github.com/
%{_datadir}/gnome-shell/extensions/apps-menu@gnome-shell-extensions.gcampax.github.com/
%{_datadir}/gnome-shell/extensions/launch-new-instance@gnome-shell-extensions.gcampax.github.com/
%{_datadir}/gnome-shell/extensions/places-menu@gnome-shell-extensions.gcampax.github.com/
%{_datadir}/gnome-shell/extensions/workspace-indicator@gnome-shell-extensions.gcampax.github.com/
%{_datadir}/gnome-shell/extensions/window-list@gnome-shell-extensions.gcampax.github.com/
%dir %{_datadir}/gnome-shell/modes
%{_datadir}/gnome-shell/modes/classic.json
%dir %{_datadir}/gnome-shell/theme/
%{_datadir}/gnome-shell/theme/calendar-today.svg
%{_datadir}/gnome-shell/theme/classic-process-working.svg
%{_datadir}/gnome-shell/theme/classic-toggle-off-intl.svg
%{_datadir}/gnome-shell/theme/classic-toggle-off-us.svg
%{_datadir}/gnome-shell/theme/classic-toggle-on-intl.svg
%{_datadir}/gnome-shell/theme/classic-toggle-on-us.svg
%{_datadir}/gnome-shell/theme/gnome-classic.css
%{_datadir}/gnome-shell/theme/gnome-classic-high-contrast.css
%{_datadir}/xsessions/gnome-classic.desktop
%{_datadir}/xsessions/sle-classic.desktop
%{_datadir}/gnome-shell/extensions/window-list@gnome-shell-extensions.gcampax.github.com/sle-classic.css
%{_datadir}/gnome-shell/modes/sle-classic.json
%{_datadir}/gnome-shell/extensions/sle-classic@suse.com/
%dir %{_datadir}/wayland-sessions
%{_datadir}/wayland-sessions/sle-classic.desktop
%if !0%{?is_opensuse}
%{_datadir}/gnome-shell/theme/sle-background.png
%{_datadir}/xsessions/default.desktop
%{_datadir}/xsessions/sle-classic-xorg.desktop
%{_datadir}/wayland-sessions/default.desktop
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%ghost %{_sysconfdir}/alternatives/default-waylandsession.desktop
%endif

%files -n gnome-shell-classic-session
%defattr(-,root,root)
%doc COPYING
%{_datadir}/gnome-session/sessions/gnome-classic.session

%files common-lang -f %{name}.lang

%changelog
* Wed May 29 2019 Yifan Jiang <yfjiang@suse.com>
- Split the architecture dependent session file to a new package
  gnome-shell-classic-session required by gnome-shell-classic.
- Move BuildArch: noarch to subpackages to enable %%ifarch macro
  (bsc#1129412).
* Fri Mar 29 2019 Yifan Jiang <yfjiang@suse.com>
- Add gnome-classic-s390-not-require-g-s-d_wacom.patch: Remove the
  gnome session runtime requirement of g-s-d Wacom plugin because
  it is not build on s390 (bsc#1129412).
* Tue Jul 17 2018 xwang@suse.com
- Update sle-classic@suse.com.tar.gz. After sle-classic extension
  is disabled, can't show clone window in overview mode
  (bsc#1095325).
* Mon Jun  4 2018 xwang@suse.com
- Update sle-classic@suse.com.tar.gz. Don't allow user to enable
  sle-classic extension in tweak tool (bsc#1095325).
* Thu Apr 19 2018 xwang@suse.com
- Update sle-classic-xorg.desktop translations (bsc#1077156).
* Thu Feb  8 2018 xwang@suse.com
- Update sle-classic-xorg.desktop translations (bsc#1077156).
* Sun Jan  7 2018 zaitor@opensuse.org
- Own {_datadir}/gnome-shell/extensions, needed after changes in
  gnome-shell package.
* Thu Dec 14 2017 xwang@suse.com
- Fix in SLE-Classic session application title bar doesn't show
  application menu (bsc#1070090 bgo#746592).
  + Update sle-classic@suse.com.tar.gz
  + Update sle-classic.desktop
  + Update sle-classic-xorg.desktop
* Fri Nov 24 2017 xwang@suse.com
- Lower update-alternative priority of sle-classic desktop to 20,
  resulting in GNOME session becoming the default session
  (fate#324384).
* Mon Nov 20 2017 xwang@suse.com
- Add gnome-shell-extensions-window-list-app-icon-not-shown.patch:
  Fix window-list doesn't show app icon on taskbar when working in
  wayland (bgo#745064).
* Thu Nov  9 2017 xwang@suse.com
- Apply SLE-Classic session on Tumbleweed (bsc#1051772).
  + Rename sle-classic-favorites-menu-at-end.patch to
    gnome-shell-favorites-menu-at-end.patch
* Mon Nov  6 2017 xwang@suse.com
- Move SLE-Classic function in gnome-shell to
  gnome-shell-extensions (bsc#1065611).
  + Update gnome-shell-add-app-to-desktop.patch
  + Update gse-sle-classic-ext.patch
  + Update sle-classic-favorites-menu-at-end.patch
  + Update sle-classic-xorg.desktop
  + Update sle-classic.desktop
  + Add sle-classic.json
  + Add sle-classic@suse.com.tar.gz
* Sat Nov  4 2017 luc14n0@linuxmail.org
- Update to version 3.26.2:
  + Updated translations.
- Update Url to
  https://wiki.gnome.org/Projects/GnomeShell/Extensions: current
  GNOME Shell Extensions project web page.
* Wed Nov  1 2017 xwang@suse.com
- Apply gnome-shell-add-app-to-desktop.patch on openSUSE
  (bsc#1061742).
* Mon Oct 30 2017 qzheng@suse.com
- Update gse-sle-classic-ext.patch, make the bottom panel
  background of SLE-Classic "black" in the Overview mode
  (bsc#1064377).
* Wed Oct 18 2017 xwang@suse.com
- Add sle-classic-xorg.desktop file.
  Allow user to open X session or wayland session (bsc#1062909).
- Add default.desktop file in '{_datadir}/wayland-sessions/'
  Make default.desktop session working on wayland (bsc#1062196).
* Tue Oct 17 2017 qzheng@suse.com
- Update gnome-shell-add-app-to-desktop.patch, allow app
  shortcut added to desktop could be executed with default
  attribute "trusted" (bsc#1055240).
* Mon Oct  9 2017 xwang@suse.com
- Update gse-sle-classic-ext.patch to version 3.26.1
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + native-window-placement: Adjust to gnome-shell changes.
  + Updated translations.
* Wed Sep 27 2017 xwang@suse.com
- Enable SLE-Classic session working on Wayland.
  Add sle-classic.desktop in folder '{_datadir}/wayland-sessions/'
  (bsc#1058797)
* Fri Sep 22 2017 dimstar@opensuse.org
- Register SLE-Classic with u-a handler for default.desktop
  implementation, which obsoletes the change in
  /etc/sysconfig/windowmanager to pick the 'default window manager'
  (boo#1039756).
* Mon Sep 18 2017 xwang@suse.com
- Update patch gse-sle-classic-ext.patch.
  Fix 'this._pureWinList is null', error involved in bsc#1046570
  fix(bsc#1046570).
* Wed Sep 13 2017 xwang@suse.com
- Update sle-classic patches to version 3.26.0:
  + Update gse-sle-classic-ext.patch
  + Update sle-classic-favorites-menu-at-end.patch
  + Update sle-classic-lock-screen-background.patch
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Updated translations.
* Sun Sep 10 2017 jengelh@inai.de
- Update package summaries. Replace historic tar option specs.
* Wed Aug 23 2017 xwang@suse.com
- Update patch gse-sle-classic-ext.patch. Fix only half panel shown
  on bottom of desktop when scaling-factor equals 2(Require patched
  gnome-shell)(bsc#1046570).
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Updated translations.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + screenshot-window-sizer: Fix backward cycling.
  + Updated translations.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + places-menu: Use mount operation if necessary.
  + window-list: Respect MWM hints.
  + Updated translations.
- Drop glib2_gsettings_schema handling in post(un), file-triggers
  takes care of this for us now.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + places-menu: Make URI launching asynchronous.
  + Updated translations.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.1:
  + apps-menu: Mark copied launchers as trusted.
  + places-menu: Make icon lookup asynchronous.
* Wed Aug  2 2017 xwang@suse.com
- Update sle-classic patches to version 3.24.3:
  + Update gnome-shell-add-app-to-desktop.patch
  + Update gse-sle-classic-ext.patch
  + Update sle-classic-favorites-menu-at-end.patch
  + Update sle-classic-lock-screen-background.patch
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + screenshot-window-sizer: Fix backward cycling.
  + Updated translations.
* Thu May 11 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + apps-menu: Mark copied launchers as trusted.
  + places-menu: Make icon lookup asynchronous.
  + Updated translations.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + apps-menu: Allow creating desktop launchers via DND.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + update classic theme.
  + Updated translations.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Updated translations.
* Thu Feb 16 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + window-list:
  - Improve styling.
  - Hide workspace indicator when there's a single (static)
    workspace.
  + Updated translations.
* Fri Nov 25 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + alternateTab: Don't take over 'switch-group' shortcut.
  + Updated translations.
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Updated translations.
* Tue Nov  1 2016 xwang@suse.com
- Add SUSE logo on lock screen when auth is requested (bsc#1007468)
  + sle-classic-lock-screen-background.patch
  + SLE-theme.tar.gz
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + window-list: Update icon on app changes.
* Tue Oct 11 2016 yfjiang@suse.com
- Enable SLE-Classic for Leap 42.2 (bnc#999655)
  + add workspace indicator back for LEAP 42.2
* Wed Sep 21 2016 cxiong@suse.com
- Enable SLE-Classic for Leap 42.2 (bnc#999655)
  + modify SPEC to re-enable SLE-Classic for Leap 42.2
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Update style.
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Updated translations.
- Add global Requires exclude for the now private typelib(Meta)
  from mutter.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Updated translations.
- Drop gnome-common BuildRequires: No longer needed as we are not
  using a git tarball anymore.
- Drop intltool BuildRequires: No longer used by upstream.
- Add pkgconfig(gio-2.0) BuildRequires: previously pulled in by
  gnome-common.
* Mon Jul 25 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + apps-menu: Fix entries from non-standard AppDir directories.
* Thu Jul 14 2016 dimstar@opensuse.org
- Update to version 3.21.3:
  + adjust to gnome-shell changes.
  + Updated translations.
- Changes from version 3.21.2:
  + version bump only.
* Mon May 23 2016 cxiong@suse.com
- Update to GNOME 3.20.2 fate#318572
  + gse-sle-classic-ext.patch updated.
* Wed May 11 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Update classic style.
  + Updated translations.
* Mon May  9 2016 cxiong@suse.com
- SLE Classic (REBASING DONE)
  + DROPPED places-menu-use-nautilus-for-links.patch (Invalid)
  + Add workspace-indicator to the build
  + Fix the gap between bottom menu and its button.
  + Fix windows auto-grouping.
  + Hide window list in Overview
  + Clean up spec file.
* Thu May  5 2016 cxiong@suse.com
- Rebasing SLE Classic (basic) (Fate#318572)
- Add source sle-classic.desktop: xsession file
- Add patch gse-sle-classic-ext.patch: add sle classic support
- DROPPED: Invalid
  + gnome-classic-exts-arrow-fix.patch
  + gnome-sle-classic-ext-build.patch
  + sle-classic.tar.bz2
* Wed Apr 20 2016 cxiong@suse.com
- Patches(none-SLE-classic) reviewing for SP2 GNOME 3.20
- REBASED:
  + gnome-shell-add-app-to-desktop.patch
- DROPPED: Upstreamed
  + gnome-shell-use-env-var-for-mode.patch
  + place-menu-handle-special-user-dirs-update.patch
  + 0001-window-list-import-gettext-for-the-right-domain.patch
  + gnome-shell-extensions-bnc872820-wm-button-layout.patch
  + bnc947381-Application-menu-selections-stop-working.patch
- DROPPED: Invalid
  + gnome-classic-move-notification-widget-above.patch
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
- Temporarily disable SLE patches and theming. It will be
  re-enabled in a later update.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + version bump, nothing to see here.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + version bump, nothing to see here.
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Version bump only, no changes.
* Fri Jan 22 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + screenshot-window-sizer: HiDPI support.
  + Fix gnome-shell component in classic session.
  + Updated translations.
* Sun Jan 10 2016 dimstar@opensuse.org
- Update to version 3.19.3:
  + native-window-placement: Don't let border overlap title.
  + apps-menu: Fix handling of .desktop files in subdirectories.
  + Updated translations.
* Sun Jan 10 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Updated translations.
* Sun Jan 10 2016 zaitor@opensuse.org
- Update to version 3.19.1:
  + Fix some theme issues.
* Sun Jan 10 2016 zaitor@opensuse.org
- Update to version 3.18.3:
  + apps-menu: Fix .desktop entries in subdirectories.
* Mon Nov 16 2015 cxiong@suse.com
- Add bnc947381-Application-menu-selections-stop-working.patch:
  Fix application menu open issue. Upstream has this fixed but no
  related bug report (bnc947381).
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix classic style issues.
* Tue Nov  3 2015 cxiong@suse.com
- Fix skewed icons in SLE Classic (bnc#948793)
  + There was a mismatch between the available space and declared
    icon size.
  + SPECFILE: a minor fix to avoid double unpacking the first
    source tarball.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + window-list: Fix accessibility of window buttons.
  + apps-menu: Fix unreliable highlight.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Bump version.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + places: Include DESKTOP when desktop icons are enabled.
  + Updated translations.
- Drop gnome-shell-reload-specials-when-xdg-user-dirs-changes.patch:
  Upstream reworked the directory monitoring.
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + window-list: Improve application ordering.
  + workspace-indicator: Use consistent workspace numbering.
* Thu Aug  6 2015 cxiong@suse.com
- Fix multiple issues related to windows grouping (bnc#933183) in
  SLE Classic
  + The old code contains multiple bugs for windows grouping
    display.
  + Fix missing AppButton for applications without desktop file
    in SLE Classic.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Updated translations.
* Mon Jul  6 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + window-list: Adjust with text-scaling-factor.
  + classic style updates.
  + Updated translations.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Updated translations.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Style updates.
  + Updated translations.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + classic: Update theme.
  + Updated translations.
* Wed Apr 22 2015 cxiong@suse.com
- Fix click event "missing" for window buttons in SLE Classic (bnc#913204)
  + No separate patch file, changes are in sle-classic.tar.bz2
  + "clicked" event in St.Button is not compatible with Clutter's event model.
    Though an upstream bug, but the exact cause is still unknown yet. Resort back
    to Clutter's native "button-press-event" to fix this for SLE Classic.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + window-list: Fix workspace indicators popup menu position.
  + apps-menu: Fix taking over panel-main-menu shortcut.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Thu Mar 19 2015 cxiong@suse.com
- Add gnome-shell-reload-specials-when-xdg-user-dirs-changes.patch.
  Let places menu handle changes of special user directories
  properly (bnc#885490, bgo#746338).
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + classic: Update theme.
  + update for mutter API changes.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Classic: Update theme.
  + systemMonitor extension was removed, as the message tray where
    it put its indicator no longer exists.
  + window-list: Adjust for gnome-shell changes.
* Sat Feb 21 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + classic: Visual refresh based on new shell theme.
  + window-list: Adjust for gnome-shell changes.
  + Updated translations.
* Wed Feb  4 2015 mgorse@suse.com
- Add a Recommends on gnome-shell-extensions-common-lang in
  gnome-shell-classic.
* Sun Jan 25 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + window-list: Improve interaction with system modal dialogs.
  + Updated translations.
* Sat Dec 20 2014 zaitor@opensuse.org
- Update to version 3.15.3.1:
  + Adjust to gnome-shell change.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + classic-mode:
  - Add high-contrast theme variant.
  - Drop .desktop file.
  + places-menu: Fix error when XDG user directories are not set
    up.
  + window-list: Add option to show on all monitors.
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + removable-drive, user-theme, window-list: Update for
    gnome-shell changes.
  + apps-menu: Fix some visual glitches.
  + Fix classic mode style.
  + Updated translations.
* Fri Dec 19 2014 badshah400@gmail.com
- Fix build failure by having the package own the directory
  /usr/share/gnome-shell/theme.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + apps-menu: Fix some visual glitches.
  + places-menu: Fix error when XDG user directories are not set
    up.
  + window-list: Update for gnome-shell changes.
* Wed Nov 26 2014 cxiong@suse.com
- Fix gnome-shell-add-app-to-desktop.patch
  + (bnc#899923). A dangled open menu would grab the focus and
    leave the system in a useless state. Close any open menus
    before any other action.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + drive-menu: Update for nautilus/gnome-shell changes.
* Wed Oct 15 2014 dimstar@opensuse.org
- Update to versoin 3.14.1:
  + alternateTab: Fix dismissing popup with Escape.
  + Some improvements to the window-list (spacing in app buttons,
    no flash when closing windows with auto-grouping).
  + Updated translations.
* Fri Sep 26 2014 federico@suse.com
- Added gnome-shell-extensions-bnc872820-wm-button-layout.patch for
  bnc872820.  This lets us have the correct defaults for the window
  manager's button layout, for the classic session mode.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Thu Sep 18 2014 cxiong@suse.com
- Fine-tune window button style, particularly the hovering effect.
  + (bnc#862615) Thanks Marcus Moeller (m.moeller@opensuse.org)
    for offering highlighting patch.
  + Highlight buttons when hovering (lighter color and darker text)
  + Add extra box shadow to make buttons more visible.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + New extension: screenshot-window-sizer.
  + window-list: Don't add sticky windows more than once.
  + Updated translations.
* Wed Sep 10 2014 cxiong@suse.com
- Add places-menu-use-nautilus-for-links.patch
  + (bnc#891919) Use Nautilus for all links in places menu and
    such avoids all unnecessary issues.
* Tue Sep  9 2014 cxiong@suse.com
- Force a monitors update to avoid background failure (bnc#893979)
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.13.91:
  + window-list: restore fitts'ability of workspace button.
  + Updated for gnome-shell changes.
  + Updated translations.
* Thu Sep  4 2014 cxiong@suse.com
- Add gnome-classic-move-notification-widget-above.patch
  + (bnc#877898) move notifications above the panel such that it
    doesn't cover part of the main panel.
- SLE Classic multiple fixes
  + Add callbacks for overview, fullscreen, monitor change event,
    such that the positioning&visibility of on-screen keyboard,
    message tray&widgets and panels are adapted accordingly
    (bnc#891560).
  + Offer a hack for restoring of xsettings.overrides. The
    counterpart is installed in Main._sessionLoaded (bnc#894048).
  + Hide the bottom panel so that the overview hiding animation
    works smoothly now. At least before we figure out why it
    doesn't work with the bottom panel. (improvement)
  + Adjust the positioning of LookingGlass. (improvement)
  + Other small changes.
* Wed Aug 27 2014 fcrozat@suse.com
- Add 0001-window-list-import-gettext-for-the-right-domain.patch:
  properly define gettext domain for window-list extension
  (bnc#893598).
* Fri Aug 22 2014 cxiong@suse.com
- Add place-menu-handle-special-user-dirs-update.patch:
  Let place menu handles changes of special user directories
  properly (bnc#885490).
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Updated translations.
* Tue Aug 12 2014 cxiong@suse.com
- Add sle-classic-favorites-menu-at-end.patch:
  put the favorites at the end of the app catogories for
  accessibility reason (bnc#890989).
* Thu Jul 24 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Updated for gnome-shell changes.
  + Updated translations.
* Mon Jul 21 2014 dliang@suse.com
- Update gnome-shell-add-app-to-desktop.patch to use system libs.
  (bnc#882421)
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Tweak preference UIs some more.
  + Fix classic mode schema overrides.
- Changes from version 3.13.2:
  + Fix sorting of grouped buttons in window list.
  + Tweak preference UIs.
- Changes from version 3.13.1:
  + Add DesktopNames key to the classic session file.
  + window-list: don't shift message tray on other monitors.
  + Updated translations.
* Fri Jul 11 2014 cxiong@suse.com
- Remove Avatar symbol from system indicators (bnc#886569)
  + No separate patch file, changes are in sle-classic.tar.bz2
  + It's not considered a good indication for log out
* Wed Jul  2 2014 fcrozat@suse.com
- Fix typo in gnome-shell-add-app-to-desktop.patch.
* Wed Jul  2 2014 cxiong@suse.com
- Add Logout symbol into system indicators, using 'sle-avatar' in SLE theme.
  (bnc#862615)
  + No separate patch file, changes are in sle-classic.tar.bz2
* Tue Jun 17 2014 dliang@suse.com
- Update gnome-shell-add-app-to-desktop.patch:
  add translate-update-upstream (bnc#882421).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Classic theme: remove rounded corners from tile previews.
  + Several fixes and improvements to the window-list. (Keep button
    order stable, don't shift message tray on other monitors).
  + auto-move-windows: several fixes and updates for api changes.
  + launch-new-instances: updates for api changes.
  + Updated translations.
* Wed Apr  2 2014 cxiong@suse.com
-  Bring back the official style for workspace indicator
  A continued improvement on (bnc#862615)
* Wed Apr  2 2014 dliang@suse.com
- Add gnome-shell-add-app-to-desktop.patch:
  Add 'open' 'Add to Favoriate' 'Add to Desktop' menu item to the
  app-menu (bnc#870580).
* Fri Mar 28 2014 cxiong@suse.com
- Implement SLE Classic Mode (bnc#862615)
  + Split changes for SLE Classic out of 'window-list' extension
  + SLE Classic is now implemented as a separate extension +
    session mode files.
    A fork of 'window-list' extension combined with other SLE
    specific tweaks.
  + "SLE Classic" is now a option for choice in Login.
    TODO translation for this part is unfinished.
  + GNOME Classic is now in vanilla state and can be selected in
    Login.
  + Various changes
    Conditional arrow patch, code refactoring.
  + NOTE: this depends on SLE Classic extension patch for GNOME
    Shell, see (request#35065).
  + add gnome-classic-exts-arrow-fix.patch
  + add patch gnome-sle-classic-ext-build.patch
  + add sle-classic.tar.bz2
  + add suse-gnome-classic.patch
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Fri Mar 21 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Nothing to see here, move on.
* Wed Mar 19 2014 fcrozat@suse.com
- Replace openSUSE by SUSE Linux Enterprise in README.SUSE
- Add a Recommends on gnome-shell-extensions-common-lang in
  gnome-shell-classic.
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Mon Mar  3 2014 cxiong@novell.com
- Add gnome-shell-use-env-var-for-mode.patch:
  use environment variable instead of command line to specify
  mode so that the session saving can work as expected (bnc#863709,
  bgo#720894).
* Thu Feb 27 2014 cxiong@novell.com
- Various fixes and some minor tweaks. (bnc#865977, bnc#862615)
  + improve indicators consistency in lock screen.
  + see comment 13 of the second bug
* Wed Feb 26 2014 cxiong@novell.com
- Various fixes (#862615)
  + This commit only some of all issues listed there.
  Plus some enhancements in window list style.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Several fixes and improvements to the window-list (can be
    scrolled, works correctly with the OSD keyboard, filters
    skip-taskbar windows, does not force all notifications to
    bold).
  + Drive-menu fixed not to show shadowed mounts.
  + Updates for gnome-shell changes (launch-new-instance,
    auto-move-windows, places-menu).
  + Build system fixes for systems without /bin/bash.
  + Updated translations.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + window-list: update for gnome-shell changes.
  + Updated translations.
* Thu Jan 23 2014 cxiong@novell.com
- Feature: Implement SUSE Classic GNOME style
  + This is a preview for review purpose mainly.
  + Only one panel that resides in the bottom.
  + Application menus, workspace&message indicators, window list
    switcher are all integrated on this panel.
* Fri Jan 17 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + Classic mode now supports session saving.
  + Updates for gnome-shell changes.
  + Updated translations.
* Fri Dec 20 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + workspace-indicator is vertically aligned now.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Updated translations.
- Changes from version 3.11.1:
  + Ignore shadowed mounts in drive-menu extension.
  + Updates for gnome-shell/gjs changes.
  + Updated translations.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + more updates and fixes for gnome-shell master changes and
    regressions (systemMonitor, window-list, apps-menu).
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Update the classic mode session and theme to work with the new
    system menu.
  + The usual round of updates and fixes for gnome-shell API
    changes.
  + Updated translations.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + xrandr-indicator was removed, as the implementation was
    incompatible with the new DisplayConfig mutter API.
  + Various extensions were updated for the 3.9.90 gnome-shell API.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + alternative-status-menu was removed entirely, as it does not
    fit in the designs of the new unified status menu.
  + Updated translations.
- Drop gnome-shell-extension-alternative-status-menu subpackage:
  the alternative status menu has been dropped.
- Remove alternative-status-menu.gschema.override source: as the
  alternative status menu no longer exists, there is no need to
  provide a configuration for it.
* Thu Jul 18 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + apps-menu: fixed handling of hot corner in case of screen
    reconfiguration.
  + alternative-status-menu now correctly honors polkit for
    hibernation.
  + user-menu now loads themes from $XDG_DATA_HOME too.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Classic mode mini extensions were replaced with a GSettings
    override specified in the .json file.
  + Styling of classic mode improved.
  + Native-window-placement is back working on 3.9.
  + Misc bug fixes.
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + apps-menu: appearance of the scrollbars was improved.
  + window-list is a little taller in classic mode (to account for
    the workspace switcher).
  + alternative-status-menu honors again the dconf configuration.
  + Updated translations.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Updates to window-list, xrandr-indicator, orkspace-indicator
    and windowsNavigator for gnome-shell changes.
  + Updated translations.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Many improvements to window-list:
  - Windows are activated by DND over them
  - Window buttons now have the right size, even if the text is
    smaller or larger than the ideal
  - Window buttons can be grouped automatically when the panel
    becomes crowded
  - Added a workspace switcher menu
  + Added keyboard navigation to apps-menu.
  + Small tweaks to classic-mode theme, in particular for menus.
  + Updated translations.
* Sat Apr 13 2013 dimstar@opensuse.org
- Change gnome-classic.desktop to invoke 'gnome' instead of
  'gnome-session'. We use a wrapper script to start gnome.
* Wed Mar 27 2013 dimstar@opensuse.org
- Fix scriptlets: move the glib2_gsettings_schema_post/postun to
  the sub-package gnome-shell-extension-alternative-status-menu:
  the .gschema.xml lives in this subpackage as well (bnc#811203).
- Add glib2_gsettings_schema_post/postun scriptlets for
  gnome-shell-classic subpackage.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Misc bug fixes to app-menu and window-list.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Various updates for shell changes.
  + Update window-list to always use application icons
  + Update apps-menu to not load subdirectories as separate
    categories
  + Updated translations.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Various fixes to make places-menu behave more like Nautilus,
    including showing the machine name in place of File System.
  + Various updates for shell changes.
  + alternative-status-menu no longer supports ConsoleKit systems,
    you need to install logind to have suspend or hibernate,
* Fri Feb  8 2013 dimstar@opensuse.org
- Create a gnome-shell-classic subpackage:
  + Pass --enable-classic-mode to configure
  + Extract CLASSIC_EXTENSIONS from configure and build those along
    the alternative-status-menu (just passing classic does not
    allow to add more extensions).
* Fri Feb  8 2013 dimstar@opensuse.org
- Update to version 3.7.5.1:
  + New extension forgotten in previous NEWS entry: windows-list.
  + Also forgotten previously: classic mode got a new GNOME2 style.
  + Build fixes.
- Changes from version 3.7.5:
  + places-menu is back in the classic extensions, with a new old
    GNOME-2 look.
  + classic mode moved the date menu to right, where we all know it
    rightly belongs.
  + apps-menu received a face-lift, with the inclusion of a reduced
    form of AxeMenu.
  + new extension in the classic set: launch-new-instance, which
    modifies the behavior of clicking in the dash and app launcher.
  + alternate-tab, native-window-placement and windowsNavigator
    updated for gnome-shell changes.
  + Updated translations.
- Drop g-s-e-power-off-elipsis.patch: mostly fixed upstream.
* Sun Jan 20 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + A separate configure switch has been added to enable classic
    mode session definitions
  + places-menu is no longer part of the classic-mode extension set
- Changes from version 3.7.3:
  + new extensions: default-min-max, static-workspaces
  + alternate-tab now uses the built-in window switcher and just
    takes over the switch-application keybinding
  + workspace-indicator: is no longer part of classic-mode
  + we now install classic-mode data files for gdm, gnome-session
    and gnome-shell, so if you enable classic-mode you get a new
    session option in GDM
- Changes from version 3.7.2:
  + fixed crashes with places-menu, windowsNavigator, alternate-tab
    and native-window-placement
  + alternate-tab now hides attached modal dialogs
  + places-menu has restored support for Nautilus 3.4
  + the default for hibernate is now to show in
    alternative-status-menu
  + some extensions are now tagged as "classic", and can be chosen
    with --enable-extensions=classic-mode
  + dock and gajim were removed at the beginning of the 3.7.1 cycle,
    as they were buggy and unmaintained
  + Updated translations.
* Sat Jan 19 2013 dimstar@opensuse.org
- Add g-s-e-power-off-elipsis.patch: "Power Off..." was changed to
  "Power Off", but a bunch of translations missed that yet.
* Fri Jan 18 2013 dimstar@opensuse.org
- Add alternative-status-menu.gschema.override: Enable hibernate by
  default for users of the packaged version of the
  alternative-status-menu extension.
* Fri Dec 28 2012 mike.catanzaro@gmail.com
- Update to version 3.6.2:
  + Ignore missing local bookmarks.
  + Support historical location for bookmarks file.
  + Don't fail for GIO errors getting the file name.
  + native-window-placement: fix disabling the extension.
- Changes from version 3.6.1:
  + Fixed alternative-status-menu for the new lock screen
  + Squashed some alternate-tab warnings
  + drive-menu now works with 3.6 again
- Changes from version 3.6.0:
  + major rework in places menu, to make it work without
    removed supporting code in the shell and to make it look like
    the nautilus sidebar
- Changes from version 3.5.91:
  + Various crashers were fixed in alternative-tab
  + auto-move-windows now can be made to work with static
    workspaces
  + place-menu is now on the left and uses symbolic icons like
    Files
  + StIconType usage was removed from all extensions, after it was
    removed in core
  + systemMonitor, xrandr-indicator, apps-menu, places-menu,
    alternative-status-menu were updated for the newer shell
- Changes from version 3.5.90:
  + alternate-tab has been reworked again, the old mode switch
    was removed and the all&thumbnails code extended to handle
    icons and filtering to the workspace
  + alternate-tab thumbnails now reflect the aspect ratio of the
    windows
  + systemMonitor now shows a tooltip above the indicator
  + native-window-placement, systemMonitor and windowsNavigator
    have been updated for the newer shell
- Changes from version 3.5.5:
  + convenience module has been relicensed to BSD, for
    compatibility with GPLv3 extensions
  + alternate-tab has been refactored and seen various
    improvements to all&thumbnails mode, including a new
    overlaid application icon
- Changes from version 3.5.4:
  + Updated translations.
- Changes from version 3.5.2:
  + removable-drive-menu is now a11y friendly
  + the dock can now be placed on any monitor, not just the
    primary
  + dock is now clipped to its monitor
  + alternative-status-menu now exposes GSettings for Suspend
    and Hibernate visibility - no UI yet
  + more gnome-shell API changes (places-menu,
    removable-drive-menu, alternative-status-menu)
  + miscellaneous bug fixes (native-window-placement, gajim,
    auto-move-windows)
  + Updated translations.
- Add glib2_gsettings_schema macros to post/postun.
* Fri May 25 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Build system improvements.
  + Updated translations.
- Changes from version 3.3.92:
  + Various updates for gnome-shell API changes (dock,
    native-window-placement).
  + local-install is now a make rule, not a shell script.
  + Updated translations.
- Changes from version 3.3.90:
  + System wide installation via "make install" is possible again.
  + alternate-tab: can now pre-activate the selected window.
  + auto-move-windows, workspace-indicator and example gained new
    preference dialogs.
  + workspace-indicator: fixed a bug wrt focus stealing prevention.
  + Updated translations.
- Changes from version 3.3.5:
  + Improvements to the build system and convenience module, making
    it easier for other extensions to use, and bringing it up to
    date with gnome-shell changes.
  + All extensions were ported to the Lang.Class framework (except
    xrandr-indicator, which is pending GDBus merge).
  + alternate-tab and dock were slightly refactored to clean up
    some old code.
- Changes from version 3.3.4:
  + native-window-placement: fixed native-window-placement with
    custom button layout.
  + windowsNavigator:
  - improved styling of tooltips.
  - fixed when used with the numeric keypad.
  + Updated translations.
- Changes from version 3.3.3:
  + alternative-status-menu no longer conflicts with other
    extensions in the user menu.
  + dock:
  - the default value of hide-effect is now move.
  - if autohide is disabled, now it pushes maximized windows
    aside.
  - updated to match current core shell styling.
  + drive-menu: changed to use media-eject icon instead of
    media-optical.
  + native-window-placement: position stategy setting was removed.
  + windowsNavigator: fixed to work with azerty keyboards.
  + Various other minor bug fixes.
  + Updated translations.
- Changes from version 3.3.2:
  + All extensions are now self-contained, including l10n and
    settings.
  + Introduce a convenience module that can be shared among all
    extensions.
  + You can know build an installable zip file with make zip-file.
  + alternative-status-menu, alternate-tab: fix for master shell.
  + apps-menu: no longer shows NoDisplay apps
- Changes from version 3.2.1:
  + alternate-tab: both modes now work with gnome-shell 3.2.
  + dock: added "move" hide effect.
  + systemMonitor:
  - now it enables/disables properly.
  - improved styling.
  + Various other bug fixes.
  + Updated translations.
- Add gnome-common BuildRequires and call to ./autogen.sh in %%setup
  as the tarball we have is generated with "git archive" (no
  tarball is published anymore upstream).
- Drop gnome-shell-extensions-fix-popup-menus.patch and
  gnome-shell-extensions-make-dock-extension-work.patch: fixed
  upstream.
- Rename gnome-shell-extension-alt-status-menu subpackage to
  gnome-shell-extension-alternative-status-menu, following upstream
  name change of the extension. Add appropriate Provides/Obsoletes
  for smooth upgrades.
- Only package the alternative-status-menu extension, as we want to
  avoid packaging extensions we don't ship by default. Users can
  get other extensions from https://extensions.gnome.org instead:
  + Remove subpackages for other extensions:
    gnome-shell-extension-alternate-tab,
    gnome-shell-extension-apps-menu,
    gnome-shell-extension-auto-move-windows,
    gnome-shell-extension-dock, gnome-shell-extension-drive-menu,
    gnome-shell-extension-gajim,
    gnome-shell-extension-native-window-placement,
    gnome-shell-extension-places-menu,
    gnome-shell-extension-systemMonitor,
    gnome-shell-extension-user-theme,
    gnome-shell-extension-windows-navigator,
    gnome-shell-extension-workspace-indicator,
    gnome-shell-extension-xrandr-indicator.
  + Add Obsoletes for all those dropped subpackages to
    gnome-shell-extensions-common, to help have smooth upgrades.
  + Remove main subpackage, as it makes no sense anymore since we
    don't build all the extensions anymore. Move README.SUSE to the
    gnome-shell-extensions-common subpackage instead.
  + Update README.SUSE to mention that other extensions are
    available on https://extensions.gnome.org.
  + Remove pkgconfig(gnome-desktop-3.0) and pkgconfig(libgtop-2.0)
    BuildRequires as they were only needed for other extensions.
  + Pass --enable-extensions=alternative-status-menu instead of
  - -enable-extensions=all to only build the
    alternative-status-menu extension.
* Sat Oct 29 2011 rbrownccb@opensuse.org
- Make it easier to install individual extensions without
  installing all of them:
  + This was happening because of the lang subpackage Recommends
    that was bringing the main subpackage, which in term was
    bringing all extensions through Recommends.
  + Create a gnome-shell-extensions-common subpackage and use it
    as a basis for the translations, by renaming the lang
    subpackage to gnome-shell-extensions-common-lang.
  + Replace gnome-shell Requires and lang Recommends in all
    extensions subpackages with a Requires on
    gnome-shell-extensions-common which leads to the same result.
* Thu Oct 20 2011 malcolmlewis@opensuse.org
- Add gnome-shell-extensions-fix-popup-menus.patch: the dock
  popup menus weren't working because a signal had been renamed
  ('popup' -> 'open-state-changed') (bgo#661484).
- Add gnome-shell-extensions-make-dock-extension-work.patch:
  without this patch, dock is invisible, but reacts on mouse
  clicks.
* Mon Oct  3 2011 malcolmlewis@opensuse.org
- Update to version 3.2.0:
  + Various updates for gnome-shell API changes.
- Changes from version 3.1.91:
  + Update for gnome-shell API changes in gajim.
- Changes from version 3.1.90:
  + All extensions have been ported to the new extension
    system (including live enable/disable).
  + xrandr-indicator no longer requires a specific gjs version.
  + windowsNavigator fixed for more than 2 workspaces.
  + Updated translations.
- Drop
  gnome-shell-extensions-fix-zero-length-warning-for-stylesheets.patch:
  fixed upstream.
- Drop gnome-common BuildRequires and call to autogen.sh: we're not
  using a git checkout anymore.
- Add intltool BuildRequires: it was implicitly brought in by
  gnome-common before.
* Tue Aug  9 2011 dimstar@opensuse.org
- Update to version 3.1.4:
  + New: A menu for changing workspace (workspace-indicator)
  + systemMonitor: lower the requirement on libgtop
  + auto-move-windows: open overview when last window on last
    workspace is closed
  + dock: implement autohiding, with various configurable effects
  + alternate-tab: more configurable implementations available
  + native-window-placement: don't rearrange the windows when the
    workspace switcher is shown/hidden
  + update for gnome-shell 3.1.4 API changes.
- Re-enable the systemMonitor extension, as the requirements were
  lowered. Remove build_systemMonitor define as the issue has been
  resolved.
- Add new recommended sub-package for workspace-indicator.
- Add pkgconfig(libgtop-2.0) BuildRequires for systemMonitor.
- Add gobject-introspection BuildRequires in order to get typelib()
  Requires for the packages.
- Remove bogus libgtop Requires from the systemMonitor package.
* Thu Jul 21 2011 vuntz@opensuse.org
- Fix various typos and other small issues in summaries and
  descriptions.
* Fri Jul  8 2011 malcolmlewis@opensuse.org
- Update to version 3.1.3:
  + New extensions added:
  - drive-menu: A menu for removable drives.
  - apps-menu: A GNOME 2 like menu for apps.
  - places-menu: A GNOME 2 like menu for places.
  - native-window-placement: Additional configurability for the
    window layout in the overview, including a mechanism similar
    to KDE4.
  - systemMonitor: A message tray indicator for CPU and memory
    usage (uses libgtop).
  + user-theme: Fixed resetting theme and support themes installed
    in /usr/share/themes.
  + alternative-status-menu: ported to gnome-shell master.
  + dock: ported to gnome-shell master, make position configurable
    (can be left or right).
  + Updated translations.
- Disable systemMonitor for now, with a %%build_systemMonitor
  macro. It requires libgtop >= 2.28.4 which is not available.
- Add schema requirements to dock extension.
- Change License field from GPLv2+ to GPL-2.0+ to conform with
  spdx.org identifier.
- Dropped %%build_drive_menu macro as it is now part of the 3.1.x
  tarball.
- Add gnome-shell-extensions-fix-zero-length-warning-for-
  stylesheets.patch, reported upstream as bgo#654274.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + bgo#647386: reverting of user-theme to default
  + bgo#647599: support globally installed themes
  + Added license and README
  + Updated translations.
- Disable drive menu extension for now, with a %%build_drive_menu
  macro. It was in git, but is not part of the 3.0.x tarballs.
* Sat Apr 30 2011 malcolmlewis@opensuse.org
- Update based on git commit f016b95 (which is nearly 3.0.1):
  + Add drive-menu extension.
* Thu Apr 28 2011 vuntz@opensuse.org
- Remove fdupes BuildRequires and call to %%fdupes as we package
  each extension in its own subpackage.
* Thu Apr 28 2011 malcolmlewis@opensuse.org
- Update based on git commit b223396 (which is nearly 3.0.1):
  + Add Alternative Status Menu extension
  + Add Gajim extension
  + Add user-theme extension
  + AlternateTab: make it work with the mouse
  + AutoMoveWindows: modify workspace management to only remove
    empty workspaces at end.
  + Dock: lower the actor to the bottom.
  + windowsNavigator:
  - support current gnome-shell
  - correct restore focus
- Split out extensions into subpackages, with
  gnome-shell-extensions having a Recommends for each of them.
* Tue Feb 22 2011 dimstar@opensuse.org
- Initial package, based on git commit b289b0f.
